@@ -15,12 +15,12 @@ class ApiClient():
     指标数据接口客户类
     '''
 
-    def __init__(self, token='', host='121.4.186.36', port=23588, log_level=logging.INFO, api_urls=None):
+    def __init__(self, token='', host='api.shducheng.net', port=80, log_level=logging.INFO, api_urls=None):
         '''
         ApiClient构造函数
         :param token: token字符串
-        :param host: 接口服务地址，默认：121.4.186.36
-        :param port: 接口服务端口，默认：23588
+        :param host: 接口服务地址，默认：api.shducheng.net
+        :param port: 接口服务端口，默认：80
         :param log_level: 日志级别，默认：logging.INFO
         :param api_urls: 接口地址服务路径
         :return:
@@ -128,7 +128,9 @@ class ApiClient():
                 df[idx[column]] = np.nan
             else:
                 df = pd.merge(df, _df, on='date', how='outer')
-        return df.set_index(['date']).sort_index().drop_duplicates()
+
+        df = df.set_index(['date']).sort_index()
+        return df.groupby(df.index).last()
 
     def save_series(self, items, overwrite=False):
         '''
